/*  XATTACH.CPP - a Q&D replacement for Novell's ATTACH

    Taylor Hutt 920204
    thutt@thama1.apgea.army.mil

    This program is release to the public domain by the author.
    No warranty is given, expressed, or implied.

    This program has been tested with Turbo C++ 1.0, and Novell's C
    Library using Netware 3.11.

    Please feel free to distribute this code, but I would ask that you
    leave this silly header intact.

    Please send all enhancments to me: thutt@thama1.apgea.army.mil.
    I will incorporate them into the program.

    If you are interested in any of the other programs I have, or
    want to know what other programs I have, send me email.

    Revision History
    Date        Initials        Comments
    ------------------------------------------------------------------
    920204    TWH            Created
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <nwbindry.h>
#include <nwconn.h>
#include <nwwrkenv.h>
#include <niterror.h>

char const     *const msgUsage = "usage: %s <server> <userid> <pw> [<quiet>]\n";
char const     *const msgLogin = "Unable to login to server %s as %s (%d)\n";
char const     *const msgAttach = "Unable to attach to server %s\n";

/* 
   This function will attach to a file server in a much more efficient
   manner than the Novell ATTACH program.  (For one thing, ATTACH is 103K,
   this is 11K (TC++ 1.00)).

   This program was first written for a PC Cron system running perl scripts.
   (Perl requires 300K runtime RAM), but it will be used also in the
   attachments to other file servers as more USATHAMA servers are added
   online.

   The return values of this program reflect the level of error:
		0: all is ok
       1: incorrect incantation
       2: Could not open a connection to requested server
       3: Could not login to requested server.

   Due to the Q&D nature of this program, Novell error codes are ignored;
   all errors are fatal.
*/
int 
main(int argc, char *argv[])
{
	WORD            ConnectionNumber;
	int             failed;
	int             quiet = 0;	// true if no output wanted

	if (argc < 4) {
		fprintf(stderr, msgUsage, argv[0]);
		return 1;
	}
	if (argc == 5) {
		// did not want to include getopt.  5 arguments means quiet
		quiet = 1;
	}
	// Open a connection to the server.  W/O the connection, it is
	// not possible to login.
	//
	// An interesting note:  If you only perform the attach, you can
	// still `logout' of the file server.  Instead of saying that you
	// have logged out, however, the system will say `detached ()'.
	// Anyone that can tell me what the () is for, wins my admiration.
	// (I am unsure of their purpose...)
	//
	failed = AttachToFileServer(strupr(argv[1]), &ConnectionNumber);
	if (failed) {
		if (!quiet) {
			fprintf(stderr, msgAttach, argv[1]);
		}
		return 2;
	}

	// I only know how to login using the `preferred' server connection.
	// This connection is used for all initial requests to the network.
	// When you logout, you will be defaulted to the `preferred' server.
	//
	SetPreferredConnectionID(ConnectionNumber);

	// perform the actual login.
	failed = LoginToFileServer(strupr(argv[2]), OT_USER, strupr(argv[3]));
	if (failed) {
		if (!quiet) {
			fprintf(stderr, msgLogin, argv[1], argv[2], failed);
		}
		DetachFromFileServer(ConnectionNumber);
		return 3;
	}
	return 0;
}
